@@ -44,9 +44,9 @@ ENABLE_BIGSH0T=1
 BIGSH0T_HEAD=0
 BIGSH0T_REVISION="8fe56f6d4e"
 DAV1D_HEAD=0
-DAV1D_REVISION="1.4.2"
+DAV1D_REVISION="1.5.0"
 AOM_HEAD=0
-AOM_REVISION="v3.8.0"
+AOM_REVISION="v3.11.0"
 ENABLE_VMAF=1
 VMAF_HEAD=0
 VMAF_REVISION="v3.0.0"
@@ -56,7 +56,7 @@ GLAXNIMATE_REVISION="origin/v0.5.4"
 ENABLE_GOPRO2GPX=1
 ENABLE_OPENCV=1
 OPENCV_HEAD=0
-OPENCV_REVISION="4.9.0"
+OPENCV_REVISION="4.10.0"
 ENABLE_LIBSPATIALAUDIO=1
 LIBSPATIALAUDIO_HEAD=1
 LIBSPATIALAUDIO_REVISION=
@@ -67,6 +67,12 @@ MLT_DISABLE_SOX=0
 ENABLE_WHISPERCPP=1
 WHISPERCPP_HEAD=1
 WHISPERCPP_REVISION=
+NV_CODEC_REVISION="sdk/12.0"
+
+PYTHON_VERSION=$(python3 --version | awk '{split($2, parts, "."); print parts[1] "." parts[2]}')
+PYTHON_VERSION_DLL=$(python3 --version | awk '{split($2, parts, "."); print parts[1]parts[2]}')
+
+QT_VERSION_X64="6.8.1"
 
 ################################################################################
 # Location of config file - if not overridden on command line
@@ -342,7 +348,7 @@ function set_globals {
     QT_LIB_DIR="$QTDIR/lib"
     QT_SHARE_DIR="$QTDIR/share/qt6"
   else
-    export QTDIR="$HOME/Qt/6.7.2/mingw_64"
+    export QTDIR="$HOME/Qt/$QT_VERSION_X64/mingw_64"
     QT_INCLUDE_DIR="$QTDIR/include"
     QT_LIB_DIR="$QTDIR/lib"
     QT_SHARE_DIR="$QTDIR"
@@ -492,7 +498,7 @@ function set_globals {
   if test 0 = "$LADSPA_HEAD" -a "$LADSPA_REVISION" ; then
     REVISIONS[5]="$LADSPA_REVISION"
   fi
-  REVISIONS[6]="sdk/12.0" # nv-codec-headers
+  REVISIONS[6]="$NV_CODEC_REVISION"
   REVISIONS[7]="" # AMF
   REVISIONS[8]=""
   if test 0 = "$BIGSH0T_HEAD" -a "$BIGSH0T_REVISION" ; then
@@ -764,7 +770,7 @@ function install_spatialaudio {
 
 function install_whispercpp {
   cmd ninja -C build install
-  cmd install -p -c build/bin/main.exe $FINAL_INSTALL_DIR/bin/whisper.cpp-main.exe
+  cmd install -p -c build/bin/whisper-cli.exe $FINAL_INSTALL_DIR/bin
   cmd mkdir -p $FINAL_INSTALL_DIR/share/shotcut/whisper_models
   cmd install -p -c models/ggml-base-q5_1.bin $FINAL_INSTALL_DIR/share/shotcut/whisper_models
 }
@@ -1207,7 +1213,7 @@ function deploy
     cmd mv bin/ffplay.exe .
     cmd mv bin/ffprobe.exe .
     cmd mv bin/glaxnimate.exe .
-    cmd mv bin/whisper.cpp-main.exe .
+    cmd mv bin/whisper-cli.exe .
     cmd rm -rf bin include etc man manifest src *.txt
     cmd rm lib/*
     cmd rm -rf lib/cmake lib/pkgconfig lib/gdk-pixbuf-2.0 lib/glib-2.0 lib/gtk-2.0
@@ -1222,7 +1228,7 @@ function deploy
 
   log Copying some libs from Qt
   if [ "$DEBUG_BUILD" != "1" -o "$SDK" = "1" ]; then
-    cmd cp -p "$QTDIR"/bin/Qt6{Charts,Core,Core5Compat,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml}.dll .
+    cmd cp -p "$QTDIR"/bin/Qt6{Charts,Core,Core5Compat,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlMeta,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml}.dll .
   fi
 
   for lib in *.dll; do
@@ -1238,12 +1244,12 @@ function deploy
   done
 
   log Copying some DLLs and python libraries for Glaxnimate
-  cmd cp -p /${TARGET_ARCH}/bin/libpython3.11.dll python311.dll
+  cmd cp -p /${TARGET_ARCH}/bin/libpython${PYTHON_VERSION}.dll python${PYTHON_VERSION_DLL}.dll
   cmd cp -p "$SOURCE_DIR"/glaxnimate/external/Qt-Color-Widgets/libQtColorWidgets.dll .
   cmd mkdir -p share/glaxnimate/glaxnimate/pythonhome/lib/python
-  cmd cp -r /${TARGET_ARCH}/lib/python3.11/*.py \
-            /${TARGET_ARCH}/lib/python3.11/lib-dynload/* \
-            /${TARGET_ARCH}/lib/python3.11/{json,collections,encodings,logging,urllib} \
+  cmd cp -r /${TARGET_ARCH}/lib/python${PYTHON_VERSION}/*.py \
+            /${TARGET_ARCH}/lib/python${PYTHON_VERSION}/lib-dynload/* \
+            /${TARGET_ARCH}/lib/python${PYTHON_VERSION}/{json,collections,encodings,logging,urllib} \
       share/glaxnimate/glaxnimate/pythonhome/lib/python
 
   log Copying some libs from mlt-prebuilt
