@@ -215,7 +215,8 @@ void FilterController::setProducer(Mlt::Producer *producer)
         m_metadataModel.updateFilterMask(!MLT.isTrackProducer(*producer),
                                          producer->type() == mlt_service_chain_type,
                                          producer->type() == mlt_service_playlist_type,
-                                         producer->type() == mlt_service_tractor_type);
+                                         producer->type() == mlt_service_tractor_type,
+                                         producer->get("mlt_service") != QString("xml-clip"));
     } else {
         setCurrentFilter(QmlFilter::DeselectCurrentFilter);
     }
