@@ -60,7 +60,8 @@
 
 static int64_t positionToMs(mlt_position position)
 {
-    return position * 1000 * MLT.profile().frame_rate_den() / MLT.profile().frame_rate_num();
+    auto seconds = position / MLT.profile().fps();
+    return 1000 * seconds;
 }
 
 static mlt_position msToPosition(int64_t ms)
@@ -171,8 +172,8 @@ SubtitlesDock::SubtitlesDock(QWidget *parent) :
     m_treeView = new QTreeView();
     vboxLayout->addWidget(m_treeView, 1);
 
-    QMenu *mainMenu = new QMenu("Subtitles", this);
-    QMenu *trackMenu = new QMenu("Tracks", this);
+    QMenu *mainMenu = new QMenu(tr("Subtitles"), this);
+    QMenu *trackMenu = new QMenu(tr("Tracks"), this);
     trackMenu->addAction(Actions["subtitleAddTrackAction"]);
     trackMenu->addAction(Actions["subtitleRemoveTrackAction"]);
     trackMenu->addAction(Actions["subtitleEditTrackAction"]);
@@ -193,8 +194,6 @@ SubtitlesDock::SubtitlesDock(QWidget *parent) :
 
     QAction *action;
     QMenu *columnsMenu = new QMenu(tr("Columns"), this);
-    action = columnsMenu->addAction(tr("Columns"));
-    action->setEnabled(false);
     action = columnsMenu->addAction(tr("Start"), this, SLOT(onStartColumnToggled(bool)));
     action->setCheckable(true);
     action->setChecked(Settings.subtitlesShowColumn("start"));
@@ -205,7 +204,7 @@ SubtitlesDock::SubtitlesDock(QWidget *parent) :
     action->setCheckable(true);
     action->setChecked(Settings.subtitlesShowColumn("duration"));
     mainMenu->addMenu(columnsMenu);
-    Actions.loadFromMenu(columnsMenu);
+    Actions.loadFromMenu(mainMenu);
 
     DockToolBar *toolbar = new DockToolBar(tr("Subtitle Controls"));
     toolbar->setAreaHint(Qt::BottomToolBarArea);
@@ -1119,7 +1118,6 @@ void SubtitlesDock::generateTextOnTimeline()
         producer.set("mlt_image_format", "rgba");
         producer.set("in", 0);
         producer.set("out", frameEnd - frameStart);
-        producer.set("length", producer.frames_to_time(frameEnd - frameStart + 1, mlt_time_clock));
         // Add a text filter
         Mlt::Filter filter(MLT.profile(), "dynamictext");
         filter.set(kShotcutFilterProperty, "dynamicText");
