@@ -89,7 +89,9 @@ void JobQueue::onProgressUpdated(QStandardItem *standardItem, int percent)
                 remaining = tr("paused");
             } else if (percent > 0) {
                 auto time = job->estimateRemaining(percent);
-                if (percent > 2 && QTime(0, 0).secsTo(time) > 0)
+                if (QTime(0, 0).secsTo(time) == 0)
+                    return;
+                if (percent > 2)
                     remaining = time.toString();
                 remaining = QStringLiteral("%1% (%2)").arg(percent).arg(remaining);
             }
