@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2024 Meltytech, LLC
+ * Copyright (c) 2012-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ AbstractJob::AbstractJob(const QString &name, QThread::Priority priority)
     , m_label(name)
     , m_startingPercent(0)
     , m_priority(priority)
+    , m_isPaused(false)
 {
     setObjectName(name);
     connect(this, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(onFinished(int,
@@ -46,12 +47,17 @@ AbstractJob::AbstractJob(const QString &name, QThread::Priority priority)
                                                                                         int)));
     m_actionPause = new QAction(tr("Pause This Job"), this);
     m_standardActions << m_actionPause;
+    m_actionPause->setEnabled(false);
     m_actionResume = new QAction(tr("Resume This Job"), this);
     m_actionResume->setEnabled(false);
     m_standardActions << m_actionResume;
 
     connect(m_actionPause, &QAction::triggered, this, &AbstractJob::pause);
     connect(m_actionResume, &QAction::triggered, this, &AbstractJob::resume);
+    connect(this, &AbstractJob::finished, this, [this]() {
+        m_actionPause->setEnabled(false);
+        m_actionResume->setEnabled(false);
+    });
 }
 
 void AbstractJob::start()
@@ -117,7 +123,7 @@ void AbstractJob::setPostJobAction(PostJobAction *action)
 
 bool AbstractJob::paused() const
 {
-    return !m_actionPause->isEnabled();
+    return m_isPaused;
 }
 
 void AbstractJob::start(const QString &program, const QStringList &arguments)
@@ -136,6 +142,7 @@ void AbstractJob::start(const QString &program, const QStringList &arguments)
     AbstractJob::start();
     m_actionPause->setEnabled(true);
     m_actionResume->setEnabled(false);
+    m_isPaused = false;
 }
 
 void AbstractJob::stop()
@@ -157,6 +164,7 @@ void AbstractJob::stop()
 
 void AbstractJob::pause()
 {
+    m_isPaused = true;
     m_actionPause->setEnabled(false);
     m_actionResume->setEnabled(true);
 
@@ -178,6 +186,7 @@ void AbstractJob::resume()
 #else
     ::kill(QProcess::processId(), SIGCONT);
 #endif
+    m_isPaused = false;
     emit progressUpdated(m_item, 0);
 }
 
@@ -204,6 +213,7 @@ void AbstractJob::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
         m_log.append(QStringLiteral("Failed with exit code %1\n").arg(exitCode));
         emit finished(this, false);
     }
+    m_isPaused = false;
 }
 
 void AbstractJob::onReadyRead()
