@@ -39,9 +39,7 @@ private slots:
 
 private:
     QStringList m_args;
-    QString m_duration;
-    bool m_outputMsgRead;
-    int m_totalFrames;
+    double m_duration;
     int m_previousPercent;
     bool m_isOpenLog;
 };
