@@ -44,6 +44,7 @@ class QUndoStack;
 class QActionGroup;
 class FilterController;
 class ScopeController;
+class FilesDock;
 class FiltersDock;
 class TimelineDock;
 class AutoSaveFile;
@@ -134,6 +135,8 @@ public:
     void cropSource(const QRectF &rect);
     void getMarkerRange(int position, int *start, int *end);
     void getSelectionRange(int *start, int *end);
+    Mlt::Playlist *binPlaylist();
+    void showInFiles(const QString &filePath);
 
 signals:
     void audioChannelsChanged();
@@ -233,6 +236,7 @@ private:
     NotesDock *m_notesDock;
     SubtitlesDock *m_subtitlesDock;
     std::unique_ptr<QWidget> m_producerWidget;
+    FilesDock *m_filesDock;
 
 public slots:
     bool isCompatibleWithGpuMode(MltXmlChecker &checker);
@@ -279,6 +283,7 @@ private slots:
     void onMarkersDockTriggered(bool = true);
     void onNotesDockTriggered(bool = true);
     void onSubtitlesDockTriggered(bool = true);
+    void onFilesDockTriggered(bool = true);
     void onPlaylistCreated();
     void onPlaylistLoaded();
     void onPlaylistCleared();
@@ -406,6 +411,7 @@ private slots:
     void on_actionAudioVideoDevice_triggered();
     void on_actionReset_triggered();
     void on_actionBackupSave_triggered();
+    void on_actionPauseAfterSeek_triggered(bool checked);
 };
 
 #define MAIN MainWindow::singleton()
