@@ -184,31 +184,10 @@ bool Controller::openXML(const QString &filename)
 {
     bool error = true;
     close();
-    if (Settings.playerGPU() && profile().is_explicit()) {
-        Profile testProfile;
-        Producer producer(testProfile, filename.toUtf8().constData());
-        if (testProfile.width() != profile().width() || testProfile.height() != profile().height()
-                || Util::isFpsDifferent(profile().fps(), testProfile.fps())) {
-            return error;
-        }
-    }
-    Producer producer(profile(), filename.toUtf8().constData());
-    if (producer.is_valid()) {
-        double fps = profile().fps();
-        if (!profile().is_explicit()) {
-            profile().from_producer(producer);
-            profile().set_width(Util::coerceMultiple(profile().width()));
-            profile().set_height(Util::coerceMultiple(profile().height()));
-        }
-        updatePreviewProfile();
-        setPreviewScale(Settings.playerPreviewScale());
-        if (Util::isFpsDifferent(profile().fps(), fps)) {
-            // reopen with the correct fps
-            producer = Producer(profile(), filename.toUtf8().constData());
-        }
-        producer.set(kShotcutVirtualClip, 1);
-        producer.set("resource", filename.toUtf8().constData());
-        setProducer(new Producer(producer));
+
+    Mlt::Producer xmlProducer = Util::openMltVirtualClip(filename);
+    if (xmlProducer.is_valid()) {
+        setProducer(new Producer(xmlProducer));
         error = false;
     }
     return error;
@@ -262,12 +241,13 @@ static void fire_jack_seek_event(mlt_properties jack, int position)
     mlt_events_fire(jack, "jack-seek", mlt_event_data_from_int(position));
 }
 
-void Controller::pause()
+void Controller::pause(int position)
 {
     if (m_producer && !isPaused()) {
         m_producer->set_speed(0);
         if (m_consumer && m_consumer->is_valid()) {
-            m_producer->seek(m_consumer->position() + 1);
+            position = position > -1 ? position : m_consumer->position() + 1;
+            m_producer->seek(position);
             m_consumer->purge();
             m_consumer->start();
             // The following fixes a bug with frame-dropping. It is possible a video frame rendering
@@ -456,7 +436,8 @@ void Controller::seek(int position)
     setVolume(m_volume, false);
     if (m_producer) {
         // Always pause before seeking (if not already paused).
-        m_producer->set_speed(0);
+        if (Settings.playerPauseAfterSeek())
+            m_producer->set_speed(0);
         m_producer->seek(position);
         if (m_consumer && m_consumer->is_valid()) {
             if (m_consumer->is_stopped()) {
@@ -468,7 +449,8 @@ void Controller::seek(int position)
         }
     }
     if (m_jackFilter) {
-        stopJack();
+        if (Settings.playerPauseAfterSeek())
+            stopJack();
         ++m_skipJackEvents;
         fire_jack_seek_event(m_jackFilter->get_properties(), position);
     }
@@ -601,12 +583,7 @@ void Controller::setProfile(const QString &profile_name)
         m_profile.set_explicit(true);
     } else {
         m_profile.set_explicit(false);
-        if (m_producer && m_producer->is_valid()
-                && (qstrcmp(m_producer->get("mlt_service"), "color")
-                    || qstrcmp(m_producer->get("resource"), "_hide"))) {
-            m_profile.from_producer(*m_producer);
-            m_profile.set_width(Util::coerceMultiple(m_profile.width()));
-        } else {
+        if (!m_producer || !m_producer->is_valid() && isClosedClip()) {
             // Use a default profile with the dummy hidden color producer.
             Mlt::Profile tmp(kDefaultMltProfile);
             m_profile.set_colorspace(tmp.colorspace());
@@ -616,6 +593,9 @@ void Controller::setProfile(const QString &profile_name)
             m_profile.set_sample_aspect(tmp.sample_aspect_num(), tmp.sample_aspect_den());
             m_profile.set_display_aspect(tmp.display_aspect_num(), tmp.display_aspect_den());
             m_profile.set_width(Util::coerceMultiple(tmp.width()));
+        } else {
+            m_profile.from_producer(*m_producer);
+            m_profile.set_width(Util::coerceMultiple(m_profile.width()));
         }
     }
     updatePreviewProfile();
@@ -678,6 +658,15 @@ bool Controller::isClip() const
     return producer() && producer()->is_valid() && !isPlaylist() && !isMultitrack();
 }
 
+bool Controller::isClosedClip(Producer *producer) const
+{
+    if (!producer)
+        producer = m_producer.data();
+    return producer && producer->is_valid() &&
+           !qstrcmp(producer->get("mlt_service"), "color") &&
+           !qstrcmp(producer->get("resource"), "_hide");
+}
+
 bool Controller::isSeekableClip()
 {
     return isClip() && isSeekable();
@@ -1463,8 +1452,9 @@ void Controller::adjustFilter(Mlt::Filter *filter, int in, int out, int inDelta,
             emit MAIN.serviceOutChanged(outDelta, filter);
 
             // Update simple keyframes
-            if (filter->get_int(kShotcutAnimOutProperty) && meta && meta->keyframes()) {
-                foreach (QString name, meta->keyframes()->simpleProperties()) {
+            if ((filter->get_int(kShotcutAnimInProperty) || filter->get_int(kShotcutAnimOutProperty)) && meta
+                    && meta->keyframes()) {
+                for (const QString &name : meta->keyframes()->simpleProperties()) {
                     if (!filter->get_animation(name.toUtf8().constData())) {
                         // Cause a string property to be interpreted as animated value.
                         if (meta->keyframes()->parameter(name)->isColor())
@@ -1477,8 +1467,12 @@ void Controller::adjustFilter(Mlt::Filter *filter, int in, int out, int inDelta,
                         int n = animation.key_count();
                         if (n > 1) {
                             animation.set_length(filter->get_length());
-                            animation.key_set_frame(n - 2, filter->get_length() - filter->get_int(kShotcutAnimOutProperty));
-                            animation.key_set_frame(n - 1, filter->get_length() - 1);
+                            if (filter->get_int(kShotcutAnimInProperty) > filter->get_length() - 1) {
+                                animation.key_set_frame(n - 1, filter->get_length() - 1);
+                            } else if (filter->get_int(kShotcutAnimOutProperty)) {
+                                animation.key_set_frame(n - 2, filter->get_length() - filter->get_int(kShotcutAnimOutProperty));
+                                animation.key_set_frame(n - 1, filter->get_length() - 1);
+                            }
                         }
                     }
                 }
@@ -1698,9 +1692,9 @@ void TransportControl::play(double speed)
     MLT.play(speed);
 }
 
-void TransportControl::pause()
+void TransportControl::pause(int position)
 {
-    MLT.pause();
+    MLT.pause(position);
 }
 
 void TransportControl::stop()
