@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2022-2023 Meltytech, LLC
+ * Copyright (c) 2022-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -155,7 +155,7 @@ QVariant ActionsModel::data(const QModelIndex &index, int role) const
 
 bool ActionsModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
-    if ( !index.isValid() )
+    if (!index.isValid() )
         return false;
 
     if (role != Qt::EditRole)
@@ -179,7 +179,7 @@ bool ActionsModel::setData(const QModelIndex &index, const QVariant &value, int
     QAction *action = m_actions[index.row()];
 
     if (!ks.isEmpty()) {
-        for (const auto a : qAsConst(m_actions)) {
+        for (const auto a : std::as_const(m_actions)) {
             QList<QKeySequence> sequences = a->shortcuts();
             for (int i = 0; i < sequences.size(); i++) {
                 if (sequences[i] == ks) {
