@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2024 Meltytech, LLC
+ * Copyright (c) 2012-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -99,7 +99,7 @@ public:
 
     QString cacheKey(int frameNumber)
     {
-        QString time = m_producer.frames_to_time(frameNumber, Settings.timeFormat());
+        QString time = m_producer.frames_to_time(frameNumber, mlt_time_clock);
         // Reduce the precision to centiseconds to increase chance for cache hit
         // without much loss of accuracy.
         time = time.left(time.size() - 1);
@@ -163,9 +163,6 @@ public:
             return QImage();
         }
     }
-
-signals:
-    void thumbnailUpdated(int row);
 };
 
 PlaylistModel::PlaylistModel(QObject *parent)
@@ -222,12 +219,15 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
             if (m_mode == Detailed && index.column() != COLUMN_THUMBNAIL)
                 return QVariant();
             field = FIELD_THUMBNAIL;
-        } else
+        } else if (role == Qt::StatusTipRole) {
+            field = FIELD_INDEX + index.column();
+        } else {
             return QVariant();
+        }
     }
 
     QScopedPointer<Mlt::ClipInfo> info(m_playlist->clip_info(index.row()));
-    if (info)
+    if (info) {
         switch (field) {
         case FIELD_INDEX:
             return QString::number(index.row() + 1);
@@ -366,7 +366,47 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
             }
             return image;
         }
+        case FIELD_MEDIA_TYPE:
+        case FIELD_MEDIA_TYPE_ENUM:
+            if (info->producer && info->producer->is_valid()) {
+                auto type = Other;
+                if (MLT.isImageProducer(info->producer)) {
+                    type = Image;
+                } else {
+                    auto service = QString::fromLatin1(info->producer->get("mlt_service"));
+                    if (service.startsWith("avformat")) {
+                        if (info->producer->get_int("video_index") > -1
+                                && Util::getSuggestedFrameRate(info->producer) != 90000)
+                            type = Video;
+                        else if (info->producer->get_int("audio_index") > -1)
+                            type = Audio;
+                    }
+                }
+                if (FIELD_MEDIA_TYPE == field) {
+                    switch (type) {
+                    case Video:
+                        return tr("Video");
+                    case Image:
+                        return tr("Image");
+                    case Audio:
+                        return tr("Audio");
+                    default:
+                        return tr("Other");
+                    }
+                }
+                return type;
+            }
+            break;
+        case FIELD_COMMENT:
+            if (info->producer && info->producer->is_valid())
+                return QString::fromUtf8(info->producer->get(kCommentProperty));
+            break;
+        case FIELD_BIN:
+            if (info->producer && info->producer->is_valid())
+                return QString::fromUtf8(info->producer->get(kShotcutBinsProperty));
+            break;
         }
+    }
     return QVariant();
 }
 
@@ -385,6 +425,46 @@ void PlaylistModel::setViewMode(ViewMode mode)
     endResetModel();
 }
 
+void PlaylistModel::setBin(int row, const QString &name)
+{
+    auto producer = m_playlist->get_clip(row);
+    if (producer && producer->is_valid()) {
+        producer->parent().set(kShotcutBinsProperty, name.toUtf8().constData());
+        emit dataChanged(createIndex(row, PlaylistModel::COLUMN_BIN),
+                         createIndex(row, PlaylistModel::COLUMN_BIN));
+        emit modified();
+    }
+}
+
+void PlaylistModel::renameBin(const QString &bin, const QString &newName)
+{
+    if (newName.isEmpty()) {
+        emit dataChanged(createIndex(0, PlaylistModel::COLUMN_BIN),
+                         createIndex(rowCount(), PlaylistModel::COLUMN_BIN));
+        emit modified();
+        return;
+    }
+
+    auto n = rowCount();
+    auto modified = false;
+    for (int row = 0; row < n; ++row) {
+        auto clip = m_playlist->get_clip(row);
+        if (clip && clip->is_valid()) {
+            if (bin == clip->parent().get(kShotcutBinsProperty)) {
+                if (newName.isEmpty())
+                    clip->parent().Mlt::Properties::clear(kShotcutBinsProperty);
+                else
+                    clip->parent().set(kShotcutBinsProperty, newName.toUtf8().constData());
+                emit dataChanged(createIndex(row, PlaylistModel::COLUMN_BIN),
+                                 createIndex(row, PlaylistModel::COLUMN_BIN));
+                modified = true;
+            }
+        }
+    }
+    if (modified)
+        emit this->modified();
+}
+
 QVariant PlaylistModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
@@ -403,6 +483,10 @@ QVariant PlaylistModel::headerData(int section, Qt::Orientation orientation, int
             return tr("Start");
         case COLUMN_DATE:
             return tr("Date");
+        case COLUMN_MEDIA_TYPE:
+            return tr("Type");
+        case COLUMN_COMMENT:
+            return tr("Comment");
         default:
             break;
         }
@@ -412,7 +496,7 @@ QVariant PlaylistModel::headerData(int section, Qt::Orientation orientation, int
 
 Qt::DropActions PlaylistModel::supportedDropActions() const
 {
-    return Qt::CopyAction | Qt::MoveAction | Qt::LinkAction;
+    return Qt::CopyAction | Qt::MoveAction;
 }
 
 bool PlaylistModel::insertRows(int row, int count, const QModelIndex &parent)
@@ -519,7 +603,7 @@ QMimeData *PlaylistModel::mimeData(const QModelIndexList &indexes) const
     }
     Mlt::Playlist playlist(MLT.profile());
     foreach (auto index, indexes) {
-        if (index.column()) continue;
+        if (m_mode == Detailed && index.column() != COLUMN_RESOURCE) continue;
         QScopedPointer<Mlt::ClipInfo> info(m_playlist->clip_info(index.row()));
         if (info && info->producer) {
             playlist.append(*info->producer, info->frame_in, info->frame_out);
@@ -527,6 +611,8 @@ QMimeData *PlaylistModel::mimeData(const QModelIndexList &indexes) const
     }
     mimeData->setData(Mlt::XmlMimeType, MLT.XML(&playlist).toUtf8());
     mimeData->setText(QString::number(count));
+    auto mimeType = QLatin1String("application/x-qabstractitemmodeldatalist");
+    mimeData->setData(mimeType, QAbstractItemModel::mimeData(indexes)->data(mimeType));
     return mimeData;
 }
 
@@ -577,22 +663,6 @@ Qt::ItemFlags PlaylistModel::flags(const QModelIndex &index) const
         return Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | defaults;
 }
 
-QModelIndex PlaylistModel::incrementIndex(const QModelIndex &index) const
-{
-    if (index.row() + 1 < rowCount())
-        return createIndex(index.row() + 1, index.column());
-    else
-        return QModelIndex();
-}
-
-QModelIndex PlaylistModel::decrementIndex(const QModelIndex &index) const
-{
-    if (index.row() > 0)
-        return createIndex(index.row() - 1, index.column());
-    else
-        return QModelIndex();
-}
-
 QModelIndex PlaylistModel::createIndex(int row, int column) const
 {
     return QAbstractTableModel::createIndex(row, column);
@@ -743,9 +813,9 @@ void PlaylistModel::close()
 void PlaylistModel::move(int from, int to)
 {
     if (!m_playlist) return;
+    beginResetModel();
     m_playlist->move(from, to);
-    emit dataChanged(createIndex(from, 0), createIndex(from, columnCount()));
-    emit dataChanged(createIndex(to, 0), createIndex(to, columnCount()));
+    endResetModel();
     emit modified();
 }
 
