@@ -69,7 +69,6 @@ Player::Player(QWidget *parent)
     , m_previousOut(-1)
     , m_duration(0)
     , m_isSeekable(false)
-    , m_isMeltedPlaying(-1)
     , m_zoomToggleFactor(Settings.playerZoom() == 0.0f ? 1.0f : Settings.playerZoom())
     , m_pauseAfterOpen(false)
     , m_monitorScreen(-1)
@@ -371,6 +370,7 @@ Player::Player(QWidget *parent)
     connect(MLT.videoWidget(), SIGNAL(frameDisplayed(const SharedFrame &)), this,
             SLOT(onFrameDisplayed(const SharedFrame &)));
     connect(m_scrubber, SIGNAL(seeked(int)), this, SLOT(seek(int)));
+    connect(m_scrubber, SIGNAL(paused(int)), this, SLOT(pause(int)));
     connect(m_scrubber, SIGNAL(inChanged(int)), this, SLOT(onInChanged(int)));
     connect(m_scrubber, SIGNAL(outChanged(int)), this, SLOT(onOutChanged(int)));
     connect(m_positionSpinner, SIGNAL(valueChanged(int)), this, SLOT(seek(int)));
@@ -399,7 +399,7 @@ void Player::connectTransport(const TransportControllable *receiver)
         disconnect(m_currentTransport);
     m_currentTransport = receiver;
     connect(this, SIGNAL(played(double)), receiver, SLOT(play(double)));
-    connect(this, SIGNAL(paused()), receiver, SLOT(pause()));
+    connect(this, SIGNAL(paused(int)), receiver, SLOT(pause(int)));
     connect(this, SIGNAL(stopped()), receiver, SLOT(stop()));
     connect(this, SIGNAL(seeked(int)), receiver, SLOT(seek(int)));
     connect(this, SIGNAL(rewound(bool)), receiver, SLOT(rewind(bool)));
@@ -582,8 +582,10 @@ void Player::setupActions()
     action = new QAction(tr("Seek End"), this);
     action->setShortcut(QKeySequence(Qt::Key_End));
     connect(action, &QAction::triggered, this, [&]() {
-        if (MLT.producer())
+        if (MLT.producer()) {
+            pause(MLT.producer()->get_length());
             seek(MLT.producer()->get_length());
+        }
     });
     Actions.add("playerSeekEndAction", action);
 
@@ -591,8 +593,10 @@ void Player::setupActions()
     action->setProperty(Actions.hardKeyProperty, "K+L");
     action->setShortcut(QKeySequence(Qt::Key_Right));
     connect(action, &QAction::triggered, this, [&]() {
-        if (MLT.producer())
+        if (MLT.producer()) {
+            pause(position() + 1);
             seek(position() + 1);
+        }
     });
     Actions.add("playerNextFrameAction", action);
 
@@ -600,8 +604,10 @@ void Player::setupActions()
     action->setProperty(Actions.hardKeyProperty, "K+J");
     action->setShortcut(QKeySequence(Qt::Key_Left));
     connect(action, &QAction::triggered, this, [&]() {
-        if (MLT.producer())
+        if (MLT.producer()) {
+            pause(position() - 1);
             seek(position() - 1);
+        }
     });
     Actions.add("playerPreviousFrameAction", action);
 
@@ -843,9 +849,9 @@ void Player::play(double speed)
     m_playPosition = m_position;
 }
 
-void Player::pause()
+void Player::pause(int position)
 {
-    emit paused();
+    emit paused(position);
     showPaused();
 }
 
@@ -862,9 +868,10 @@ void Player::seek(int position)
             emit seeked(qMin(position, MLT.isMultitrack() ? m_duration : m_duration - 1));
         }
     }
-    // Seek implies pause.
-    Actions["playerPlayPauseAction"]->setIcon(m_playIcon);
-    m_playPosition = std::numeric_limits<int>::max();
+    if (Settings.playerPauseAfterSeek()) {
+        Actions["playerPlayPauseAction"]->setIcon(m_playIcon);
+        m_playPosition = std::numeric_limits<int>::max();
+    }
 }
 
 void Player::reset()
@@ -934,67 +941,34 @@ void Player::onProducerOpened(bool play)
 
     connectTransport(MLT.transportControl());
 
-    // Closing the previous producer might call pause() milliseconds before
-    // calling play() here. Delays while purging the consumer on pause can
-    // interfere with the play() call. So, we delay play a little to let
-    // pause purging to complete.
-    if (play) {
+    if (play || (MLT.isClip() && !MLT.isClosedClip())) {
         if (m_pauseAfterOpen) {
             m_pauseAfterOpen = false;
-            QTimer::singleShot(500, this, SLOT(postProducerOpened()));
-            if (!MLT.isClip()) {
+            QTimer::singleShot(500, this, [ = ]() {
+                if (MLT.producer())
+                    pause(MLT.producer()->position());
+            });
+            if (MLT.isClip()) {
+                pause();
+            } else {
                 MLT.producer()->seek(0);
             }
         } else {
-            if (MLT.consumer()->is_stopped()) {
-                QTimer::singleShot(500, this, SLOT(play()));
-            } else {
+            // Closing the previous producer might call pause() milliseconds before
+            // calling play() here. Delays while purging the consumer on pause can
+            // interfere with the play() call. So, we delay play a little to let
+            // pause purging to complete.
+            if (!MLT.consumer()->is_stopped()) {
                 // This seek purges the consumer to prevent latent end-of-stream detection.
                 seek(0);
-                QTimer::singleShot(500, this, SLOT(play()));
             }
+            QTimer::singleShot(500, this, SLOT(play()));
         }
+    } else {
+        pause(0);
     }
 }
 
-void Player::postProducerOpened()
-{
-    if (MLT.producer())
-        seek(MLT.producer()->position());
-}
-
-void Player::onMeltedUnitOpened()
-{
-    m_isMeltedPlaying = -1; // unknown
-    m_duration = MLT.producer()->get_length();
-    m_isSeekable = true;
-    MLT.producer()->set("ignore_points", 1);
-    m_scrubber->setFramerate(MLT.profile().fps());
-    m_scrubber->setScale(m_duration);
-    m_scrubber->setMarkers(QList<int>());
-    m_inPointLabel->setText(blankTime());
-    m_selectedLabel->setText(blankTime());
-    m_durationLabel->setText(QString(MLT.producer()->get_length_time(Settings.timeFormat())));
-    MLT.producer()->get_length_time(mlt_time_clock);
-    m_previousIn = MLT.producer()->get_in();
-    m_scrubber->setEnabled(true);
-    m_scrubber->setInPoint(m_previousIn);
-    m_previousOut = MLT.producer()->get_out();
-    m_scrubber->setOutPoint(m_previousOut);
-    m_positionSpinner->setEnabled(m_isSeekable);
-    setVolume(m_volumeSlider->value());
-    m_savedVolume = MLT.volume();
-    onMuteButtonToggled(Settings.playerMuted());
-    Actions["playerPlayPauseAction"]->setEnabled(true);
-    Actions["playerSkipPreviousAction"]->setEnabled(m_isSeekable);
-    Actions["playerSkipNextAction"]->setEnabled(m_isSeekable);
-    Actions["playerRewindAction"]->setEnabled(m_isSeekable);
-    Actions["playerFastForwardAction"]->setEnabled(m_isSeekable);
-    setIn(-1);
-    setOut(-1);
-    setFocus();
-}
-
 void Player::onDurationChanged()
 {
     m_duration = MLT.producer()->get_length();
@@ -1007,7 +981,7 @@ void Player::onDurationChanged()
     if (MLT.producer()->get_speed() == 0)
         seek(m_position);
     else if (m_position >= m_duration)
-        seek(m_duration - 1);
+        pause(m_duration - 1);
 }
 
 void Player::onFrameDisplayed(const SharedFrame &frame)
@@ -1031,7 +1005,7 @@ void Player::onFrameDisplayed(const SharedFrame &frame)
         m_positionSpinner->blockSignals(false);
         m_scrubber->onSeek(position);
         if (m_playPosition < m_previousOut && m_position >= m_previousOut && !loop) {
-            seek(m_previousOut);
+            pause(m_previousOut);
         }
     }
     if (loop) {
