@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2024 Meltytech, LLC
+ * Copyright (c) 2013-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include <QMediaDevices>
 #include <QAudioDevice>
 #include <Logger.h>
+#include <qdesktopservices.h>
 
 static const QString APP_DATA_DIR_KEY("appdatadir");
 static const QString SHOTCUT_INI_FILENAME("/shotcut.ini");
@@ -323,6 +324,116 @@ void ShotcutSettings::setViewMode(const QString &viewMode)
     emit viewModeChanged();
 }
 
+QString ShotcutSettings::filesViewMode() const
+{
+    return settings.value("files/viewMode", QLatin1String("tiled")).toString();
+}
+
+void ShotcutSettings::setFilesViewMode(const QString &viewMode)
+{
+    settings.setValue("files/viewMode", viewMode);
+    emit filesViewModeChanged();
+}
+
+QStringList ShotcutSettings::filesLocations() const
+{
+    QStringList result;
+    for (const auto &s : settings.value("files/locations").toStringList()) {
+        if (!s.startsWith("__"))
+            result << s;
+    }
+    return result;
+}
+
+QString ShotcutSettings::filesLocationPath(const QString &name) const
+{
+    QString key = QStringLiteral("files/location/%1").arg(name);
+    return settings.value(key).toString();
+}
+
+bool ShotcutSettings::setFilesLocation(const QString &name, const QString &path)
+{
+    bool isNew = false;
+    QStringList locations = filesLocations();
+    if (!locations.contains(name)) {
+        isNew = true;
+        locations.append(name);
+        settings.setValue("files/locations", locations);
+    }
+    settings.setValue("files/location/" + name, path);
+    return isNew;
+}
+
+bool ShotcutSettings::removeFilesLocation(const QString &name)
+{
+    QStringList list = filesLocations();
+    int index = list.indexOf(name);
+    if (index > -1) {
+        list.removeAt(index);
+        if (list.isEmpty())
+            settings.remove("files/locations");
+        else
+            settings.setValue("files/locations", list);
+        settings.remove("files/location/" + name);
+        return true;
+    }
+    return false;
+}
+
+QStringList ShotcutSettings::filesOpenOther(const QString &type) const
+{
+    return settings.value("files/openOther/" + type).toStringList();
+}
+
+void ShotcutSettings::setFilesOpenOther(const QString &type, const QString &filePath)
+{
+    QStringList filePaths = filesOpenOther(type);
+    filePaths.removeAll(filePath);
+    filePaths.append(filePath);
+    settings.setValue("files/openOther/" + type, filePaths);
+}
+
+bool ShotcutSettings::removeFilesOpenOther(const QString &type, const QString &filePath)
+{
+    QStringList list = filesOpenOther(type);
+    int index = list.indexOf(filePath);
+    if (index > -1) {
+        list.removeAt(index);
+        if (list.isEmpty())
+            settings.remove("files/openOther/" + type);
+        else
+            settings.setValue("files/openOther/" + type, list);
+        return true;
+    }
+    return false;
+}
+
+QString ShotcutSettings::filesCurrentDir() const
+{
+    const auto ls = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
+    auto path = settings.value("files/currentDir", ls.first()).toString();
+    if (!QFile::exists(path)) {
+        LOG_DEBUG() << "dir does not exist:" << QDir::toNativeSeparators(path);
+        path = ls.first();
+    }
+    return path;
+}
+
+void ShotcutSettings::setFilesCurrentDir(const QString &s)
+{
+    settings.setValue("files/currentDir", s);
+}
+
+bool ShotcutSettings::filesFoldersOpen() const
+{
+    return settings.value("files/foldersOpen", true).toBool();
+}
+
+void ShotcutSettings::setFilesFoldersOpen(bool b)
+{
+    settings.setValue("files/foldersOpen", b);
+}
+
 QString ShotcutSettings::exportFrameSuffix() const
 {
     return settings.value("exportFrameSuffix", ".png").toString();
@@ -619,6 +730,16 @@ void ShotcutSettings::setPlayerAudioDriver(const QString &s)
     settings.setValue("player/audioDriver", s);
 }
 
+bool ShotcutSettings::playerPauseAfterSeek() const
+{
+    return settings.value("player/pauseAfterSeek", true).toBool();
+}
+
+void ShotcutSettings::setPlayerPauseAfterSeek(bool b)
+{
+    settings.setValue("player/pauseAfterSeek", b);
+}
+
 QString ShotcutSettings::playlistThumbnails() const
 {
     return settings.value("playlist/thumbnails", "small").toString();
@@ -882,6 +1003,28 @@ void ShotcutSettings::setVideoOutDuration(double d)
     emit videoOutDurationChanged();
 }
 
+int ShotcutSettings::audioInCurve() const
+{
+    return settings.value("filter/audioInCurve", mlt_keyframe_linear).toInt();
+}
+
+void ShotcutSettings::setAudioInCurve(int c)
+{
+    settings.setValue("filter/audioInCurve", c);
+    emit audioInCurveChanged();
+}
+
+int ShotcutSettings::audioOutCurve() const
+{
+    return settings.value("filter/audioOutCurve", mlt_keyframe_linear).toInt();
+}
+
+void ShotcutSettings::setAudioOutCurve(int c)
+{
+    settings.setValue("filter/audioOutCurve", c);
+    emit audioOutCurveChanged();
+}
+
 bool ShotcutSettings::askOutputFilter() const
 {
     return settings.value("filter/askOutput", true).toBool();
@@ -1352,9 +1495,9 @@ QString ShotcutSettings::whisperExe()
 {
     QDir dir(qApp->applicationDirPath());
 #if defined(Q_OS_WIN)
-    auto exe = "whisper.cpp-main.exe";
+    auto exe = "whisper-cli.exe";
 #else
-    auto exe = "whisper.cpp-main";
+    auto exe = "whisper-cli";
 #endif
     return settings.value("subtitles/whisperExe", dir.absoluteFilePath(exe)).toString();
 }
