@@ -62,6 +62,10 @@ class ShotcutSettings : public QObject
                videoInDurationChanged)
     Q_PROPERTY(double videoOutDuration READ videoOutDuration WRITE setVideoOutDuration NOTIFY
                videoOutDurationChanged)
+    Q_PROPERTY(double audioInCurve READ audioInCurve WRITE setAudioInCurve NOTIFY
+               audioInCurveChanged)
+    Q_PROPERTY(double audioOutCurve READ audioOutCurve WRITE setAudioOutCurve NOTIFY
+               audioOutCurveChanged)
     Q_PROPERTY(bool smallIcons READ smallIcons WRITE setSmallIcons NOTIFY smallIconsChanged)
     Q_PROPERTY(bool askOutputFilter READ askOutputFilter WRITE setAskOutputFilter NOTIFY
                askOutputFilterChanged)
@@ -180,6 +184,8 @@ public:
     void setPlayerJumpSeconds(double);
     QString playerAudioDriver() const;
     void setPlayerAudioDriver(const QString &s);
+    bool playerPauseAfterSeek() const;
+    void setPlayerPauseAfterSeek(bool);
 
     // playlist
     QString playlistThumbnails() const;
@@ -234,6 +240,10 @@ public:
     void setVideoInDuration(double);
     double videoOutDuration() const;
     void setVideoOutDuration(double);
+    int audioInCurve() const;
+    void setAudioInCurve(int);
+    int audioOutCurve() const;
+    void setAudioOutCurve(int);
     bool askOutputFilter() const;
     void setAskOutputFilter(bool);
 
@@ -345,6 +355,21 @@ public:
     void setNotesZoom(int zoom);
     int notesZoom() const;
 
+    // Files
+    QString filesViewMode() const;
+    void setFilesViewMode(const QString &viewMode);
+    QStringList filesLocations() const;
+    QString filesLocationPath(const QString &name) const;
+    bool setFilesLocation(const QString &name, const QString &path);
+    bool removeFilesLocation(const QString &name);
+    QStringList filesOpenOther(const QString &type) const;
+    void setFilesOpenOther(const QString &type, const QString &filePath);
+    bool removeFilesOpenOther(const QString &type, const QString &filePath);
+    QString filesCurrentDir() const;
+    void setFilesCurrentDir(const QString &s);
+    bool filesFoldersOpen() const;
+    void setFilesFoldersOpen(bool b);
+
 public slots:
     void reset();
 
@@ -366,8 +391,11 @@ signals:
     void audioOutDurationChanged();
     void videoInDurationChanged();
     void videoOutDurationChanged();
+    void audioInCurveChanged();
+    void audioOutCurveChanged();
     void playlistThumbnailsChanged();
     void viewModeChanged();
+    void filesViewModeChanged();
     void smallIconsChanged();
     void askOutputFilterChanged();
     void timelineScrollingChanged();
