@@ -678,6 +678,8 @@ void AvformatProducerWidget::on_menuButton_clicked()
 {
     QMenu menu;
     menu.addAction(ui->actionReset);
+    if (!MLT.resource().contains("://")) // not a network stream
+        menu.addAction(ui->actionShowInFiles);
     if (!MLT.resource().contains("://")) // not a network stream
         menu.addAction(ui->actionOpenFolder);
     menu.addAction(ui->actionCopyFullFilePath);
@@ -1420,3 +1422,8 @@ void AvformatProducerWidget::on_actionBitrateViewer_triggered()
     job->setLabel(tr("Bitrate %1").arg(Util::baseName(args.last())));
     JOBS.add(job);
 }
+
+void AvformatProducerWidget::on_actionShowInFiles_triggered()
+{
+    emit showInFiles(Util::GetFilenameFromProducer(producer()));
+}
