@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ Mlt::Producer *ImageProducerWidget::newProducer(Mlt::Profile &profile)
 {
     QString resource = QString::fromUtf8(m_producer->get("resource"));
     if (!resource.contains("?begin=") && m_producer->get("begin")) {
-        resource.append(QString("?begin=%1").arg(m_producer->get("begin")));
+        resource.append(QStringLiteral("?begin=%1").arg(m_producer->get("begin")));
     }
     LOG_DEBUG() << resource;
     Mlt::Producer *p = new Mlt::Producer(profile, resource.toUtf8().constData());
@@ -90,7 +90,7 @@ void ImageProducerWidget::setProducer(Mlt::Producer *p)
     resource = QDir::toNativeSeparators(resource);
     ui->filenameLabel->setToolTip(resource);
     bool isProxy = m_producer->get_int(kIsProxyProperty) && m_producer->get(kOriginalResourceProperty);
-    ui->resolutionLabel->setText(QString("%1x%2 %3").arg(p->get("meta.media.width")).arg(
+    ui->resolutionLabel->setText(QStringLiteral("%1x%2 %3").arg(p->get("meta.media.width")).arg(
                                      p->get("meta.media.height"))
                                  .arg(isProxy ? tr("(PROXY)") : ""));
     ui->aspectNumSpinBox->blockSignals(true);
@@ -266,7 +266,7 @@ void ImageProducerWidget::on_sequenceCheckBox_clicked(bool checked)
             begin.prepend(name[i - 1]);
         if (count) {
             m_producer->set("begin", begin.toLatin1().constData());
-            name.replace(i, count, QString("0%1d").arg(count).prepend('%'));
+            name.replace(i, count, QStringLiteral("0%1d").arg(count).prepend('%'));
             QString serviceName = m_producer->get("mlt_service");
             if (!serviceName.isEmpty())
                 resource = serviceName + ":" + info.path() + "/" + name;
@@ -340,6 +340,8 @@ void ImageProducerWidget::on_notesTextEdit_textChanged()
 void ImageProducerWidget::on_menuButton_clicked()
 {
     QMenu menu;
+    if (!MLT.resource().contains("://")) // not a network stream
+        menu.addAction(ui->actionShowInFiles);
     if (!MLT.resource().contains("://")) // not a network stream
         menu.addAction(ui->actionOpenFolder);
     menu.addAction(ui->actionCopyFullFilePath);
@@ -469,3 +471,8 @@ void ImageProducerWidget::on_proxyButton_clicked()
     ui->actionDisableProxy->setChecked(proxyDisabled);
     menu.exec(ui->proxyButton->mapToGlobal(QPoint(0, 0)));
 }
+
+void ImageProducerWidget::on_actionShowInFiles_triggered()
+{
+    emit showInFiles(GetFilenameFromProducer(producer()));
+}
