@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2023 Meltytech, LLC
+ * Copyright (c) 2016-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,12 +26,17 @@
 #include <QMouseEvent>
 #include <QtMath>
 #include <QScrollBar>
+#include <QSortFilterProxyModel>
+
+static const auto kPaddingPx = 10;
+static const auto kFilesSizeFactor = 1.5f;
 
 PlaylistIconView::PlaylistIconView(QWidget *parent)
     : QAbstractItemView(parent)
     , m_gridSize(170, 100)
     , m_draggingOverPos(QPoint())
     , m_itemsPerRow(3)
+    , m_iconRole(Qt::DecorationRole)
 {
     verticalScrollBar()->setSingleStep(100);
     verticalScrollBar()->setPageStep(400);
@@ -41,6 +46,8 @@ PlaylistIconView::PlaylistIconView(QWidget *parent)
 
 QRect PlaylistIconView::visualRect(const QModelIndex &index) const
 {
+    if (!index.isValid())
+        return QRect();
     int row = index.row() / m_itemsPerRow;
     int col = index.row() % m_itemsPerRow;
     return QRect(col * m_gridSize.width(), row * m_gridSize.height(),
@@ -51,14 +58,12 @@ void PlaylistIconView::rowsInserted(const QModelIndex &parent, int start, int en
 {
     QAbstractItemView::rowsInserted(parent, start, end);
     updateSizes();
-    viewport()->update();
 }
 
 void PlaylistIconView::rowsAboutToBeRemoved(const QModelIndex &parent, int start, int end)
 {
     QAbstractItemView::rowsAboutToBeRemoved(parent, start, end);
     updateSizes();
-    viewport()->update();
 }
 
 void PlaylistIconView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight,
@@ -66,7 +71,6 @@ void PlaylistIconView::dataChanged(const QModelIndex &topLeft, const QModelIndex
 {
     QAbstractItemView::dataChanged(topLeft, bottomRight, roles);
     updateSizes();
-    viewport()->update();
 }
 
 void PlaylistIconView::selectionChanged(const QItemSelection &selected,
@@ -92,7 +96,7 @@ QModelIndex PlaylistIconView::indexAt(const QPoint &point) const
 
     int row = (point.y() + verticalScrollBar()->value()) / m_gridSize.height();
     int col = (point.x() / m_gridSize.width()) % m_itemsPerRow;
-    return model()->index(row * m_itemsPerRow + col, 0);
+    return model()->index(row * m_itemsPerRow + col, 0, rootIndex());
 }
 
 QModelIndex PlaylistIconView::moveCursor(CursorAction cursorAction, Qt::KeyboardModifiers modifiers)
@@ -161,20 +165,22 @@ void PlaylistIconView::paintEvent(QPaintEvent *)
     const auto proxy = tr("P", "The first letter or symbol of \"proxy\"");
     const auto oldFont = painter.font();
     auto boldFont(oldFont);
+
+    painter.setRenderHints(QPainter::TextAntialiasing | QPainter::SmoothPixmapTransform);
     boldFont.setBold(true);
     painter.fillRect(rect(), pal.base());
 
     if (!model())
         return;
 
-    QAbstractItemModel *m = model();
+    auto proxyModel = static_cast<QSortFilterProxyModel *>(model());
     QRect dragIndicator;
 
-    for (int row = 0; row <= m->rowCount() / m_itemsPerRow; row++) {
+    for (int row = 0; row <= proxyModel->rowCount(rootIndex()) / m_itemsPerRow; row++) {
         for (int col = 0; col < m_itemsPerRow; col++) {
             const int rowIdx = row * m_itemsPerRow + col;
 
-            QModelIndex idx = m->index(rowIdx, 0);
+            QModelIndex idx = proxyModel->index(rowIdx, 0, rootIndex());
             if (!idx.isValid())
                 break;
 
@@ -185,11 +191,17 @@ void PlaylistIconView::paintEvent(QPaintEvent *)
                 continue;
 
             const bool selected = selectedIndexes().contains(idx);
-            const QImage thumb = idx.data(Qt::DecorationRole).value<QImage>();
+            QImage thumb = proxyModel->mapToSource(idx).data(m_iconRole).value<QImage>();
+
+            if (m_iconRole != Qt::DecorationRole) { // Files
+                thumb = thumb.scaled(PlaylistModel::THUMBNAIL_WIDTH * kFilesSizeFactor,
+                                     PlaylistModel::THUMBNAIL_HEIGHT * kFilesSizeFactor,
+                                     Qt::KeepAspectRatio, Qt::SmoothTransformation);
+            }
 
             QRect imageBoundingRect = itemRect;
             imageBoundingRect.setHeight(0.7 * imageBoundingRect.height());
-            imageBoundingRect.adjust(0, 10, 0, 0);
+            imageBoundingRect.adjust(0, kPaddingPx, 0, 0);
 
             QRect imageRect(QPoint(), thumb.size());
             imageRect.moveCenter(imageBoundingRect.center());
@@ -215,7 +227,7 @@ void PlaylistIconView::paintEvent(QPaintEvent *)
             }
 
             painter.drawImage(imageRect, thumb);
-            QStringList nameParts = idx.data(Qt::DisplayRole).toString().split('\n');
+            QStringList nameParts = proxyModel->mapToSource(idx).data(Qt::DisplayRole).toString().split('\n');
             if (nameParts.size() > 1) {
                 const auto indexPos = imageRect.topLeft() + QPoint(5, 15);
                 painter.setFont(boldFont);
@@ -282,7 +294,7 @@ void PlaylistIconView::dropEvent(QDropEvent *event)
         index = index.sibling(index.row() + 1, index.column());
 
     const Qt::DropAction action = event->dropAction();
-    int row = (index.row() != -1) ? index.row() : model()->rowCount();
+    int row = (index.row() != -1) ? index.row() : model()->rowCount(rootIndex());
     if (model()->dropMimeData(event->mimeData(), action, row, index.column(), index))
         event->acceptProposedAction();
 
@@ -301,7 +313,6 @@ void PlaylistIconView::setModel(QAbstractItemModel *model)
 {
     QAbstractItemView::setModel(model);
     updateSizes();
-    viewport()->update();
 }
 
 void PlaylistIconView::keyPressEvent(QKeyEvent *event)
@@ -331,13 +342,16 @@ QAbstractItemView::DropIndicatorPosition PlaylistIconView::position(const QPoint
 
 void PlaylistIconView::updateSizes()
 {
-    if (!model() || !model()->rowCount()) {
+    if (!model() || !model()->rowCount(rootIndex())) {
         verticalScrollBar()->setRange(0, 0);
         return;
     }
 
     QSize size;
-    if (Settings.playlistThumbnails() == "tall")
+    if (m_iconRole != Qt::DecorationRole) // Files
+        size = QSize(PlaylistModel::THUMBNAIL_WIDTH * kFilesSizeFactor,
+                     PlaylistModel::THUMBNAIL_HEIGHT * kFilesSizeFactor);
+    else if (Settings.playlistThumbnails() == "tall")
         size = QSize(PlaylistModel::THUMBNAIL_WIDTH, PlaylistModel::THUMBNAIL_HEIGHT * 2);
     else if (Settings.playlistThumbnails() == "large")
         size = QSize(PlaylistModel::THUMBNAIL_WIDTH * 2, PlaylistModel::THUMBNAIL_HEIGHT * 2);
@@ -346,7 +360,7 @@ void PlaylistIconView::updateSizes()
     else
         size = QSize(PlaylistModel::THUMBNAIL_WIDTH, PlaylistModel::THUMBNAIL_HEIGHT);
 
-    size.setWidth(size.width() + 10);
+    size.setWidth(size.width() + kPaddingPx);
 
     m_itemsPerRow = qMax(1, viewport()->width() / size.width());
     m_gridSize = QSize(viewport()->width() / m_itemsPerRow, size.height() + 40);
@@ -355,7 +369,8 @@ void PlaylistIconView::updateSizes()
         return;
 
     verticalScrollBar()->setRange(0,
-                                  m_gridSize.height() * model()->rowCount() / m_itemsPerRow - height() + m_gridSize.height());
+                                  m_gridSize.height() * model()->rowCount(rootIndex()) / m_itemsPerRow - height() +
+                                  m_gridSize.height());
     viewport()->update();
 }
 
@@ -364,3 +379,8 @@ void PlaylistIconView::resetMultiSelect()
     m_isToggleSelect = false;
     m_isRangeSelect = false;
 }
+
+void PlaylistIconView::setIconRole(int role)
+{
+    m_iconRole = role;
+}
