@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2021 Meltytech, LLC
+ * Copyright (c) 2016-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ class PlaylistIconView : public QAbstractItemView
 public:
     PlaylistIconView(QWidget *parent);
     void resetMultiSelect();
+    void setIconRole(int role);
 
     QRect visualRect(const QModelIndex &index) const Q_DECL_OVERRIDE;
     void scrollTo(const QModelIndex &index, ScrollHint hint = EnsureVisible) Q_DECL_OVERRIDE;
@@ -53,13 +54,13 @@ public:
     void dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight,
                      const QVector<int> &roles = QVector<int>()) Q_DECL_OVERRIDE;
 
+public slots:
+    void updateSizes();
+
 protected slots:
     void selectionChanged(const QItemSelection &selected,
                           const QItemSelection &deselected) Q_DECL_OVERRIDE;
 
-private slots:
-    void updateSizes();
-
 private:
     int rowWidth() const;
     QAbstractItemView::DropIndicatorPosition position(const QPoint &pos, const QRect &rect,
@@ -71,6 +72,7 @@ private:
     bool m_isToggleSelect {false};
     bool m_isRangeSelect {false};
     QModelIndex m_pendingSelect;
+    int m_iconRole;
 };
 
 #endif
